TO DO
======================

- lctest
    - Schema and validator for YAML file
    - Add SPOBS1 StationXML file
- spectral
    - Add overlap plot
    - Add codes for noise cleaning
Use `reStructuredText
<http://docutils.sourceforge.net/rst.html>`_ to modify this file.
